@@ -35,7 +35,7 @@
 #include "file_io.h"
 #include "sample.h"
 
-//#define DEBUG_GUSPAT
+/* #define DEBUG_GUSPAT */
 #ifdef DEBUG_GUSPAT
 #define GUSPAT_FILENAME_DEBUG(dx) fprintf(stderr,"\r%s\n",dx)
 
@@ -94,9 +94,9 @@ static int convert_8sp(uint8_t *data, struct _sample *gus_sample) {
     gus_sample->data = (int16_t *) calloc((new_length + 2), sizeof(int16_t));
     if (__builtin_expect((gus_sample->data != NULL), 1)) {
         write_data = gus_sample->data;
-        do {
+        while (read_data < read_end) {
             *write_data++ = (*read_data++) << 8;
-        } while (read_data != read_end);
+        }
 
         *write_data = (*read_data++ << 8);
         write_data_a = write_data + dloop_length;
@@ -114,10 +114,8 @@ static int convert_8sp(uint8_t *data, struct _sample *gus_sample) {
         *write_data = (*read_data++ << 8);
         *write_data_b++ = *write_data;
         read_end = data + gus_sample->data_length;
-        if (__builtin_expect((read_data != read_end), 1)) {
-            do {
-                *write_data_b++ = (*read_data++) << 8;
-            } while (read_data != read_end);
+        while (read_data < read_end) {
+            *write_data_b++ = (*read_data++) << 8;
         }
         gus_sample->loop_start += loop_length;
         gus_sample->loop_end += dloop_length;
@@ -243,9 +241,9 @@ static int convert_8up(uint8_t *data, struct _sample *gus_sample) {
     gus_sample->data = (int16_t *) calloc((new_length + 2), sizeof(int16_t));
     if (__builtin_expect((gus_sample->data != NULL), 1)) {
         write_data = gus_sample->data;
-        do {
+        while (read_data < read_end) {
             *write_data++ = ((*read_data++) ^ 0x80) << 8;
-        } while (read_data != read_end);
+        }
 
         *write_data = ((*read_data++) ^ 0x80) << 8;
         write_data_a = write_data + dloop_length;
@@ -263,11 +261,10 @@ static int convert_8up(uint8_t *data, struct _sample *gus_sample) {
         *write_data = ((*read_data++) ^ 0x80) << 8;
         *write_data_b++ = *write_data;
         read_end = data + gus_sample->data_length;
-        if (__builtin_expect((read_data != read_end), 1)) {
-            do {
-                *write_data_b++ = ((*read_data++) ^ 0x80) << 8;
-            } while (read_data != read_end);
+        while (read_data < read_end) {
+            *write_data_b++ = ((*read_data++) ^ 0x80) << 8;
         }
+
         gus_sample->loop_start += loop_length;
         gus_sample->loop_end += dloop_length;
         gus_sample->data_length = new_length;
@@ -826,15 +823,15 @@ struct _sample * _WM_load_gus_pat(const char *filename, int fix_release) {
                             | ((gus_sample->loop_fraction & 0xf0) >> 4);
         }
 
-        // All sorts of annoying things happen with pat files.
-        // One of them is that the sustained release time and
-        // normal release time gets mixed up because software got muddled
+        /* All sorts of annoying things happen with pat files.
+           One of them is that the sustained release time and
+           normal release time gets mixed up because software got muddled */
         envsusreltime = env_time_table[gus_patch[gus_ptr + 40]];
         envreltime = env_time_table[gus_patch[gus_ptr + 41]];
         if (envsusreltime < envreltime) {
-            // EXPERIMENTAL
+            /* EXPERIMENTAL */
             gus_patch[gus_ptr + 40] = gus_patch[gus_ptr + 41];
-            // timidity does this:
+            /* timidity does this: */
             gus_patch[gus_ptr + 41] = 0x3f;
             gus_patch[gus_ptr + 42] = 0x3f;
 
@@ -843,7 +840,7 @@ struct _sample * _WM_load_gus_pat(const char *filename, int fix_release) {
             gus_patch[gus_ptr + 48] = 0;
         }
 
-        // lets set up the envelope data
+        /* lets set up the envelope data */
         for (i = 0; i < 6; i++) {
             GUSPAT_INT_DEBUG("Envelope #",i);
             if (gus_sample->modes & SAMPLE_ENVELOPE) {
