@@ -100,6 +100,7 @@ extern int amiga_getch (unsigned char *ch);
 #ifdef AUDIODRV_AHI
 #include <devices/ahi.h>
 #ifdef __amigaos4__
+#include <dos/obsolete.h>
 #define SHAREDMEMFLAG MEMF_SHARED
 #else
 #define SHAREDMEMFLAG MEMF_PUBLIC
@@ -118,13 +119,7 @@ static int msleep(unsigned long millisec);
 #ifdef AUDIODRV_ALSA
 #  include <alsa/asoundlib.h>
 #elif defined AUDIODRV_OSS
-#   if defined HAVE_SYS_SOUNDCARD_H
-#   include <sys/soundcard.h>
-#   elif defined HAVE_MACHINE_SOUNDCARD_H
-#   include <machine/soundcard.h>
-#   elif defined HAVE_SOUNDCARD_H
-#   include <soundcard.h> /* less common, but exists. */
-#   endif
+#  include <sys/soundcard.h>
 #elif defined AUDIODRV_OPENAL
 #   ifndef __APPLE__
 #   include <al.h>
@@ -391,6 +386,28 @@ static void resume_output_nop(void) {
  */
 static char midi_file[1024];
 
+static void mk_midifile_name(const char *src) {
+    char *p;
+    int len;
+
+    strncpy(midi_file, src, sizeof(midi_file) - 1);
+    midi_file[sizeof(midi_file) - 1] = 0;
+
+    p = strrchr(midi_file, '.');
+    if (p && (len = strlen(p)) <= 4) {
+        if (p - midi_file <= (int)sizeof(midi_file) - 5) {
+            memcpy(p, ".mid", 5);
+            return;
+        }
+    }
+
+    len = strlen(midi_file);
+    if (len > (int)sizeof(midi_file) - 5)
+        len = (int)sizeof(midi_file) - 5;
+    p = &midi_file[len];
+    memcpy(p, ".mid", 5);
+}
+
 static int write_midi_output(void *output_data, int output_size) {
     if (midi_file[0] == '\0')
         return (-1);
@@ -1858,7 +1875,7 @@ int main(int argc, char **argv) {
         if (play_from != 0) {
             WildMidi_FastSeek(midi_ptr, &play_from);
             if (play_to < play_from) {
-                // Ignore --playto if set less than --playfrom
+                /* Ignore --playto if set less than --playfrom */
                 play_to = 0;
             }
         }
@@ -1975,15 +1992,9 @@ int main(int argc, char **argv) {
                         WildMidi_ClearError();
                     } else {
                         char *real_file = FIND_LAST_DIRSEP(argv[optind-1]);
-                        if (!real_file) real_file = argv[optind];
+                        if (!real_file) real_file = argv[optind-1];
                         else real_file++;
-
-                        strncpy(midi_file, real_file, strlen(real_file));
-                        midi_file[strlen(real_file)-4] = '.';
-                        midi_file[strlen(real_file)-3] = 'm';
-                        midi_file[strlen(real_file)-2] = 'i';
-                        midi_file[strlen(real_file)-1] = 'd';
-
+                        mk_midifile_name(real_file);
                         printf("\rWriting %s: %u bytes.\r\n", midi_file, getmidisize);
                         write_midi_output(getmidibuffer,getmidisize);
                         free(getmidibuffer);
@@ -2018,7 +2029,7 @@ int main(int argc, char **argv) {
                 } else {
                     samples = (play_to - wm_info->current_sample) << 2;
                     if (!samples) {
-                        // We are at or past where we wanted to play to
+                        /* We are at or past where we wanted to play to */
                         break;
                     }
                 }
